==> nuxeo-webengine-base-7.3-sources.jar: org/nuxeo/ecm/core/rest/DocumentFactory.java <==
/*
 * (C) Copyright 2006-2008 Nuxeo SAS (http://nuxeo.com/) and contributors.
 *
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the GNU Lesser General Public License
 * (LGPL) version 2.1 which accompanies this distribution, and is available at
 * http://www.gnu.org/licenses/lgpl.html
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * Contributors:
 *     bstefanescu
 *
 * $Id$
 */

package org.nuxeo.ecm.core.rest;

import org.nuxeo.ecm.core.api.ClientException;
import org.nuxeo.ecm.core.api.DocumentModel;
import org.nuxeo.ecm.core.api.DocumentRef;
import org.nuxeo.ecm.core.api.PathRef;
import org.nuxeo.ecm.webengine.WebException;
import org.nuxeo.ecm.webengine.model.WebContext;

/**
 * @author <a href="mailto:bs@nuxeo.com">Bogdan Stefanescu</a>
 */
public class DocumentFactory {

    // Utility class.
    private DocumentFactory() {
    }

    public static DocumentObject newDocumentRoot(WebContext ctx, String path) {
        return new DocumentRoot(ctx, path);
    }

    public static DocumentObject newDocumentRoot(WebContext ctx, DocumentRef ref) {
        return new DocumentRoot(ctx, ref);
    }

    public static DocumentObject newDocumentRoot(WebContext ctx, DocumentModel doc) {
        return new DocumentRoot(ctx, doc);
    }

    public static DocumentObject newDocument(WebContext ctx, String path) {
        try {
            PathRef pathRef = new PathRef(path);
            DocumentModel doc = ctx.getCoreSession().getDocument(pathRef);
            return (DocumentObject) ctx.newObject(doc.getType(), doc);
        } catch (ClientException e) {
            throw WebException.wrap(e);
        }
    }

    public static DocumentObject newDocument(WebContext ctx, DocumentRef ref) {
        try {
            DocumentModel doc = ctx.getCoreSession().getDocument(ref);
            return (DocumentObject) ctx.newObject(doc.getType(), doc);
        } catch (ClientException e) {
            throw WebException.wrap(e);
        }
    }

    public static DocumentObject newDocument(WebContext ctx, DocumentModel doc) {
        try {
            return (DocumentObject) ctx.newObject(doc.getType(), doc);
        } catch (ClientException e) {
            throw WebException.wrap(e);
        }
    }

}

==> nuxeo-webengine-base-7.10-sources.jar: org/nuxeo/ecm/core/rest/DocumentFactory.java <==
/*
 * (C) Copyright 2006-2008 Nuxeo SAS (http://nuxeo.com/) and contributors.
 *
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the GNU Lesser General Public License
 * (LGPL) version 2.1 which accompanies this distribution, and is available at
 * http://www.gnu.org/licenses/lgpl.html
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * Contributors:
 *     bstefanescu
 *
 * $Id$
 */

package org.nuxeo.ecm.core.rest;

import org.nuxeo.ecm.core.api.DocumentModel;
import org.nuxeo.ecm.core.api.DocumentRef;
import org.nuxeo.ecm.core.api.NuxeoException;
import org.nuxeo.ecm.core.api.PathRef;
import org.nuxeo.ecm.webengine.WebException;
import org.nuxeo.ecm.webengine.model.WebContext;

/**
 * @author <a href="mailto:bs@nuxeo.com">Bogdan Stefanescu</a>
 */
public class DocumentFactory {

    // Utility class.
    private DocumentFactory() {
    }

    public static DocumentObject newDocumentRoot(WebContext ctx, String path) {
        return new DocumentRoot(ctx, path);
    }

    public static DocumentObject newDocumentRoot(WebContext ctx, DocumentRef ref) {
        return new DocumentRoot(ctx, ref);
    }

    public static DocumentObject newDocumentRoot(WebContext ctx, DocumentModel doc) {
        return new DocumentRoot(ctx, doc);
    }

    public static DocumentObject newDocument(WebContext ctx, String path) {
        try {
            PathRef pathRef = new PathRef(path);
            DocumentModel doc = ctx.getCoreSession().getDocument(pathRef);
            return (DocumentObject) ctx.newObject(doc.getType(), doc);
        } catch (NuxeoException e) {
            throw WebException.wrap(e);
        }
    }

    public static DocumentObject newDocument(WebContext ctx, DocumentRef ref) {
        try {
            DocumentModel doc = ctx.getCoreSession().getDocument(ref);
            return (DocumentObject) ctx.newObject(doc.getType(), doc);
        } catch (NuxeoException e) {
            throw WebException.wrap(e);
        }
    }

    public static DocumentObject newDocument(WebContext ctx, DocumentModel doc) {
        try {
            return (DocumentObject) ctx.newObject(doc.getType(), doc);
        } catch (NuxeoException e) {
            throw WebException.wrap(e);
        }
    }

}
